==> mediawiki-1.6.12.tbz: www/mediawiki/languages/MessagesTh.php <==
<?php


/* private */ $wgAllMessagesTh = array(

# User Toggles
#

"tog-underline" => "ขีดเส้นใต้ลิงก์",
"tog-highlightbroken" => "จัดลิงก์ที่ไม่มี <a href=\"\" class=\"new\">เป็น ดังนี้</a> (หรือ เป็นดังนี้<a href=\"\" class=\"internal\">?</a>).",
"tog-justify"	=> "จัดย่อหน้าให้เรียบร้อย",
"tog-hideminor" => "ไม่แสดงการแก้ไขย่อยใน recent changes",
"tog-usenewrc" => "Enhanced recent changes (ไม่สามารถใช้ได้กับทุกเว็บบราวเซอร์)",
"tog-numberheadings" => "ใส่ตัวเลขหน้าหัวข้อโดยอัตโนมัติ",
"tog-showtoolbar" => "Show edit toolbar",
"tog-editondblclick" => "แก้ไขหน้าโดยใช้ double click (ผ่าน JavaScript)",
"tog-editsection"=>"สามารถแก้ไขเฉพาะส่วนโดยใช้ลิงก์ [แก้ไข]",
"tog-editsectiononrightclick"=>"สามารถแก้ไขเฉพาะส่วนโดยใช้ right click<br /> บนชื่อส่วนย่อย (ผ่าน JavaScript)",
"tog-showtoc"=>"แสดงสารบัญ<br />(สำหรับบทความที่มีมากกว่า 3 หัวข้อ)",
"tog-rememberpassword" => "จำ password ระหว่าง session",
"tog-editwidth" => "กล่องสำหรับการแก้ไขกว้างเต็มหน้าจอ",
"tog-watchdefault" => "นำหน้าที่แก้ไขไปใส่ watchlist",
"tog-minordefault" => "กำหนด default ให้การแก้ไขทุกครั้งเป็นการแก้ไขย่อย",
"tog-previewontop" => "แสดง preview ก่อนกล่องสำหรับการแก้ไข",
"tog-nocache" => "ไม่นำหน้าต่าง ๆ มาใส่ใน cache",


# Dates
#

'sunday' => "วันอาทิตย์",
'monday' => "วันจันทร์",
'tuesday' => "วันอังคาร",
'wednesday' => "วันพุธ",
'thursday' => "วันพฤหัสบดี",
'friday' => "วันศุกร์",
'saturday' => "วันเสาร์",
'january' => "มกราคม",
'february' => "กุมภาพันธ์",
'march' => "มีนาคม",
'april' => "เมษายน",
'may_long' => "พฤษภาคม",
'june' => "มิถุนายน",
'july' => "กรกฎาคม",
'august' => "สิงหาคม",
'september' => "กันยายน",
'october' => "ตุลาคม",
'november' => "พฤศจิกายน",
'december' => "ธันวาคม",
'jan' => "ม.ค.",
'feb' => "ก.พ.",
'mar' => "มี.ค.",
'apr' => "เม.ย.",
'may' => "พ.ค.",
'jun' => "มิ.ย.",
'jul' => "ก.ค.",
'aug' => "ส.ค.",
'sep' => "ก.ย.",
'oct' => "ต.ค.",
'nov' => "พ.ย.",
'dec' => "ธ.ค.",

# Bits of text used by many pages:
#
"categories" => "ประเภทของหน้า",
"category" => "ประเภท",
"category_header" => "บทความในประเภท \"$1\"",
"subcategories" => "ประเภทย่อย",

"linktrail"		=> "/^([a-z]+)(.*)\$/sD",
"mainpage"		=> "หน้าหลัก",
"mainpagetext"	=> "Wiki software  ถูกติดตั้งเรียบร้อยแล้ว",
"about"			=> "เกี่ยวกับ",
"aboutsite"      => "เกี่ยวกับ {{SITENAME}}",
"aboutpage"		=> "{{ns:project}}:เกี่ยวกับ",
"help"			=> "ความช่วยเหลือ",
"helppage"		=> "{{ns:project}}:ความช่วยเหลือ",
"bugreports"	=> "รายงาน bug",
"bugreportspage" => "{{ns:project}}:รายงาน bug",
"sitesupport"   => "การบริจาค",
"faq"			=> "FAQ",
"faqpage"		=> "{{ns:project}}:FAQ",
"edithelp"		=> "ความช่วยเหลือในการแก้ไขหน้า",
"edithelppage"	=> "{{ns:project}}:การแก้ไขหน้า",
"cancel"		=> "ยกเลิก",
"qbfind"		=> "ค้นหา",
"qbbrowse"		=> "ค้น",
"qbedit"		=> "แก้ไข",
"qbpageoptions" => "หน้านี้",
"qbpageinfo"	=> "บริบท",
"qbmyoptions"	=> "หน้าของฉัน",
"qbspecialpages"	=> "หน้าพิเศษ",
"moredotdotdot"	=> "อื่น ๆ ...",
"mypage"		=> "หน้าของฉัน",
"mytalk"		=> "หน้าพูดคุยของฉัน",
"currentevents" => "เหตุการณ์ปัจจุบัน",
"errorpagetitle" => "ความผิดพลาด",
"returnto"		=> "กลับไปยัง $1.",
"tagline"      	=> "จาก {{SITENAME}}, สารานุกรมฟรี",
"whatlinkshere"	=> "หน้าที่ลิงก์มายังที่นี่",
"help"			=> "ความช่วยเหลือ",
"search"		=> "ค้นหา",
"go"		=> "ไป",
"history"		=> "ประวัติของหน้านี้",
"printableversion" => "Printable version",
"editthispage"	=> "แก้ไขหน้านี้",
"deletethispage" => "ลบหน้านี้",
"protectthispage" => "ป้องกันหน้านี้",
"unprotectthispage" => "ยกเลิกการป้องกันหน้านี้",
"newpage" => "หน้าใหม่",
"talkpage"		=> "พูดคุยเกี่ยวกับหน้านี้",
"postcomment"   => "Post a comment",
"articlepage"	=> "View article",
"subjectpage"	=> "View subject", # For compatibility
"userpage" => "View user page",
"wikipediapage" => "View meta page",
"imagepage" => 	"View image page",
"viewtalkpage" => "View discussion",
"otherlanguages" => "Other languages",
"redirectedfrom" => "(Redirected from $1)",
"lastmodified"	=> "This page was last modified $1.",
"viewcount"		=> "This page has been accessed $1 times.",
"printsubtitle" => "(From {{SERVER}})",
"protectedpage" => "Protected page",
"administrators" => "{{ns:project}}:Administrators",
"sysoptitle"	=> "Sysop access required",
"sysoptext"		=> "The action you have requested can only be
performed by users with \"sysop\" status.
See $1.",
"developertitle" => "Developer access required",
"developertext"	=> "The action you have requested can only be
performed by users with \"developer\" status.
See $1.",

"nbytes"		=> "$1 ไบต์",
"go"			=> "ไป",
"ok"			=> "OK",
"sitetitle"		=> "{{SITENAME}}",
"sitesubtitle"	=> "",
"retrievedfrom" => "Retrieved from \"$1\"",
"newmessageslink" => "ข้อความ",
"editsection"=>"แก้ไข",
"toc" => "สารบัญ",
"showtoc" => "แสดงสารบัญ",
"hidetoc" => "ซ่อนสารบัญ",
"thisisdeleted" => "แสดงหรือคืน $1?",
"restorelink" => "$1 การแก้ไขที่ลบแล้ว",

# Main script and global functions
#
"nosuchaction"	=> "ไม่มีการกระทำดังกล่าว",
"nosuchactiontext" => "การกระทำที่บอกไว้ใน URL ไม่
เป็นที่ยอมรับของ wiki",
"nosuchspecialpage" => "ไม่มีหน้าพิเศษดังกล่าว",
"nospecialpagetext" => "คุณได้ขอหน้าพิเศษที่ไม่
เป็นที่ยอมรับของ wiki",

# Login and logout pages
#
"loginpagetitle" => "ล็อกอินผู้ใช้",
"yourname"		=> "ชื่อผู้ใช้",
"yourpassword"	=> "รหัสผ่าน",
"yourpasswordagain" => "พิมพ์รหัสผ่านอีกครั้ง",
"newusersonly"	=> " (เฉพาะผู้ใช้ใหม่)",

"login"			=> "ล็อกอิน",
"loginprompt"           => "ต้อง enable cookie เพื่อล็อกอินสู่ {{SITENAME}} ได้",
"userlogin"		=> "ล็อกอิน",
"logout"		=> "ล็อกเอาท์",
"userlogout"	=> "ล็อกเอาท์",
"notloggedin"	=> "ไม่ได้ล็อกอินไว้",
"createaccount"	=> "สร้าง account ใหม่",
"createaccountmail"	=> "ผ่านอีเมล์",
"badretype"		=> "รหัสผ่านที่พิมพ์ไว้ไม่เหมือนกัน",
"userexists"	=> "ชื่อผู้ใช้ที่พิมพ์ไว้ถูกใช้แล้ว โปรดเลือกชื่ออื่น",
"youremail"		=> "อีเมล์ของคุณ*",

# Edit pages
#
"newarticletext" =>
"คุณได้ตามลิงก์ที่นำไปยังหน้าที่ยังไม่ปรากฏอยู่
เพื่อเริ่มสร้างหน้าใหม่ พิมพ์ลงในกล่องข้างล่างนี้
(ดู[[{{ns:project}}:ความช่วยเหลือ|หน้าความช่วยเหลือ]]สำหรับข้อมูลเพิ่มเติม)
If you are here by mistake, just click your browser's '''back''' button.",
"noarticletext" => "(ไม่มีข้อความในหน้านี้)",
"updated"		=> "(ได้รับการแก้ไขแล้ว)",

);


?>

==> mediawiki-1.7.3.tbz: www/mediawiki/languages/MessagesTh.php <==
<?php


/* private */ $wgAllMessagesTh = array(

# User Toggles
#

"tog-underline" => "ขีดเส้นใต้ลิงก์",
"tog-highlightbroken" => "จัดลิงก์ที่ไม่มี <a href=\"\" class=\"new\">เป็น ดังนี้</a> (หรือ เป็นดังนี้<a href=\"\" class=\"internal\">?</a>).",
"tog-justify"	=> "จัดย่อหน้าให้เรียบร้อย",
"tog-hideminor" => "ไม่แสดงการแก้ไขย่อยใน recent changes",
"tog-usenewrc" => "Enhanced recent changes (ไม่สามารถใช้ได้กับทุกเว็บบราวเซอร์)",
"tog-numberheadings" => "ใส่ตัวเลขหน้าหัวข้อโดยอัตโนมัติ",
"tog-showtoolbar" => "Show edit toolbar",
"tog-editondblclick" => "แก้ไขหน้าโดยใช้ double click (ผ่าน JavaScript)",
"tog-editsection"=>"สามารถแก้ไขเฉพาะส่วนโดยใช้ลิงก์ [แก้ไข]",
"tog-editsectiononrightclick"=>"สามารถแก้ไขเฉพาะส่วนโดยใช้ right click<br /> บนชื่อส่วนย่อย (ผ่าน JavaScript)",
"tog-showtoc"=>"แสดงสารบัญ<br />(สำหรับบทความที่มีมากกว่า 3 หัวข้อ)",
"tog-rememberpassword" => "จำ password ระหว่าง session",
"tog-editwidth" => "กล่องสำหรับการแก้ไขกว้างเต็มหน้าจอ",
"tog-watchdefault" => "นำหน้าที่แก้ไขไปใส่ watchlist",
"tog-minordefault" => "กำหนด default ให้การแก้ไขทุกครั้งเป็นการแก้ไขย่อย",
"tog-previewontop" => "แสดง preview ก่อนกล่องสำหรับการแก้ไข",
"tog-nocache" => "ไม่นำหน้าต่าง ๆ มาใส่ใน cache",


# Dates
#

'sunday' => "วันอาทิตย์",
'monday' => "วันจันทร์",
'tuesday' => "วันอังคาร",
'wednesday' => "วันพุธ",
'thursday' => "วันพฤหัสบดี",
'friday' => "วันศุกร์",
'saturday' => "วันเสาร์",
'january' => "มกราคม",
'february' => "กุมภาพันธ์",
'march' => "มีนาคม",
'april' => "เมษายน",
'may_long' => "พฤษภาคม",
'june' => "มิถุนายน",
'july' => "กรกฎาคม",
'august' => "สิงหาคม",
'september' => "กันยายน",
'october' => "ตุลาคม",
'november' => "พฤศจิกายน",
'december' => "ธันวาคม",
'jan' => "ม.ค.",
'feb' => "ก.พ.",
'mar' => "มี.ค.",
'apr' => "เม.ย.",
'may' => "พ.ค.",
'jun' => "มิ.ย.",
'jul' => "ก.ค.",
'aug' => "ส.ค.",
'sep' => "ก.ย.",
'oct' => "ต.ค.",
'nov' => "พ.ย.",
'dec' => "ธ.ค.",

# Bits of text used by many pages:
#
"categories" => "ประเภทของหน้า",
"category" => "ประเภท",
"category_header" => "บทความในประเภท \"$1\"",
"subcategories" => "ประเภทย่อย",

"linktrail"		=> "/^([a-z]+)(.*)\$/sD",
"mainpage"		=> "หน้าหลัก",
"mainpagetext"	=> "Wiki software  ถูกติดตั้งเรียบร้อยแล้ว",
"about"			=> "เกี่ยวกับ",
"aboutsite"      => "เกี่ยวกับ {{SITENAME}}",
"aboutpage"		=> "{{ns:project}}:เกี่ยวกับ",
"help"			=> "ความช่วยเหลือ",
"helppage"		=> "{{ns:project}}:ความช่วยเหลือ",
"bugreports"	=> "รายงาน bug",
"bugreportspage" => "{{ns:project}}:รายงาน bug",
"sitesupport"   => "การบริจาค",
"faq"			=> "FAQ",
"faqpage"		=> "{{ns:project}}:FAQ",
"edithelp"		=> "ความช่วยเหลือในการแก้ไขหน้า",
"edithelppage"	=> "{{ns:project}}:การแก้ไขหน้า",
"cancel"		=> "ยกเลิก",
"qbfind"		=> "ค้นหา",
"qbbrowse"		=> "ค้น",
"qbedit"		=> "แก้ไข",
"qbpageoptions" => "หน้านี้",
"qbpageinfo"	=> "บริบท",
"qbmyoptions"	=> "หน้าของฉัน",
"qbspecialpages"	=> "หน้าพิเศษ",
"moredotdotdot"	=> "อื่น ๆ ...",
"mypage"		=> "หน้าของฉัน",
"mytalk"		=> "หน้าพูดคุยของฉัน",
"currentevents" => "เหตุการณ์ปัจจุบัน",
"errorpagetitle" => "ความผิดพลาด",
"returnto"		=> "กลับไปยัง $1.",
"tagline"      	=> "จาก {{SITENAME}}, สารานุกรมฟรี",
"whatlinkshere"	=> "หน้าที่ลิงก์มายังที่นี่",
"help"			=> "ความช่วยเหลือ",
"search"		=> "ค้นหา",
"go"		=> "ไป",
"history"		=> "ประวัติของหน้านี้",
"printableversion" => "Printable version",
"editthispage"	=> "แก้ไขหน้านี้",
"deletethispage" => "ลบหน้านี้",
"protectthispage" => "ป้องกันหน้านี้",
"unprotectthispage" => "ยกเลิกการป้องกันหน้านี้",
"newpage" => "หน้าใหม่",
"talkpage"		=> "พูดคุยเกี่ยวกับหน้านี้",
"postcomment"   => "Post a comment",
"articlepage"	=> "View article",
"subjectpage"	=> "View subject", # For compatibility
"userpage" => "View user page",
"projectpage" => "View meta page",
"imagepage" => 	"View image page",
"viewtalkpage" => "View discussion",
"otherlanguages" => "Other languages",
"redirectedfrom" => "(Redirected from $1)",
"lastmodified"	=> "This page was last modified $1.",
"viewcount"		=> "This page has been accessed $1 times.",
"protectedpage" => "Protected page",
"administrators" => "{{ns:project}}:Administrators",
"sysoptitle"	=> "Sysop access required",
"sysoptext"		=> "The action you have requested can only be
performed by users with \"sysop\" status.
See $1.",
"developertitle" => "Developer access required",
"developertext"	=> "The action you have requested can only be
performed by users with \"developer\" status.
See $1.",

"nbytes"		=> "$1 ไบต์",
"go"			=> "ไป",
"ok"			=> "OK",
"sitetitle"		=> "{{SITENAME}}",
"sitesubtitle"	=> "",
"retrievedfrom" => "Retrieved from \"$1\"",
"newmessageslink" => "ข้อความ",
"editsection"=>"แก้ไข",
"editold"=>"แก้ไข",
"toc" => "สารบัญ",
"showtoc" => "แสดงสารบัญ",
"hidetoc" => "ซ่อนสารบัญ",
"thisisdeleted" => "แสดงหรือคืน $1?",
"restorelink" => "$1 การแก้ไขที่ลบแล้ว",

# Main script and global functions
#
"nosuchaction"	=> "ไม่มีการกระทำดังกล่าว",
"nosuchactiontext" => "การกระทำที่บอกไว้ใน URL ไม่
เป็นที่ยอมรับของ wiki",
"nosuchspecialpage" => "ไม่มีหน้าพิเศษดังกล่าว",
"nospecialpagetext" => "คุณได้ขอหน้าพิเศษที่ไม่
เป็นที่ยอมรับของ wiki",

# Login and logout pages
#
"loginpagetitle" => "ล็อกอินผู้ใช้",
"yourname"		=> "ชื่อผู้ใช้",
"yourpassword"	=> "รหัสผ่าน",
"yourpasswordagain" => "พิมพ์รหัสผ่านอีกครั้ง",

"login"			=> "ล็อกอิน",
"loginprompt"           => "ต้อง enable cookie เพื่อล็อกอินสู่ {{SITENAME}} ได้",
"userlogin"		=> "ล็อกอิน",
"logout"		=> "ล็อกเอาท์",
"userlogout"	=> "ล็อกเอาท์",
"notloggedin"	=> "ไม่ได้ล็อกอินไว้",
"createaccount"	=> "สร้าง account ใหม่",
"createaccountmail"	=> "ผ่านอีเมล์",
"badretype"		=> "รหัสผ่านที่พิมพ์ไว้ไม่เหมือนกัน",
"userexists"	=> "ชื่อผู้ใช้ที่พิมพ์ไว้ถูกใช้แล้ว โปรดเลือกชื่ออื่น",
"youremail"		=> "อีเมล์ของคุณ*",

# Edit pages
#
"newarticletext" =>
"คุณได้ตามลิงก์ที่นำไปยังหน้าที่ยังไม่ปรากฏอยู่
เพื่อเริ่มสร้างหน้าใหม่ พิมพ์ลงในกล่องข้างล่างนี้
(ดู[[{{ns:project}}:ความช่วยเหลือ|หน้าความช่วยเหลือ]]สำหรับข้อมูลเพิ่มเติม)
If you are here by mistake, just click your browser's '''back''' button.",
"noarticletext" => "(ไม่มีข้อความในหน้านี้)",
"updated"		=> "(ได้รับการแก้ไขแล้ว)",

);


?>
